LoggingRequestInterceptor class

Request interceptor for logging requests

Inheritance

Constructors

LoggingRequestInterceptor({required void logger(String message)})

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → void Function(String message)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(AxiosError error) FutureOr<void>
Called when an error occurs
inherited
onRequest(AxiosRequest request) FutureOr<AxiosRequest>
Called before the request is sent
override
onResponse(AxiosResponse response) FutureOr<AxiosResponse>
Called when the response is received
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited