AxiosResponse<T> class
Represents an HTTP response in the Axios style
Constructors
- AxiosResponse({required T data, required int status, required String statusText, required Headers headers, required AxiosRequest request, String? rawData})
-
const
Properties
- data → T
-
Response data (parsed)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers → Headers
-
Response headers
final
- isClientError → bool
-
Whether the response indicates a client error
no setter
- isError → bool
-
Whether the response indicates an error
no setter
- isServerError → bool
-
Whether the response indicates a server error
no setter
- isSuccess → bool
-
Whether the response indicates success
no setter
- rawData → String?
-
Raw response data (before parsing)
final
- request → AxiosRequest
-
The request configuration that produced this response
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int
-
HTTP status code
final
- statusText → String
-
HTTP status message
final
Methods
-
copyWith(
{T? data, int? status, String? statusText, Headers? headers, AxiosRequest? request, String? rawData}) → AxiosResponse< T> - Create a copy with some values replaced
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited