StreamedAxiosResponse<T> class
流式响应类
Constructors
-
StreamedAxiosResponse({required int status, required String statusText, required Map<
String, String> headers, required Stream<T> dataStream, required AxiosRequest request, int? contentLength}) -
const
Properties
- contentLength → int?
-
内容长度(如果可用)
final
-
dataStream
→ Stream<
T> -
数据流
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
响应头
final
- isSuccess → bool
-
是否成功响应
no setter
- request → AxiosRequest
-
原始请求
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int
-
HTTP 状态码
final
- statusText → String
-
HTTP 状态文本
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited